import logging
from typing import List

from peek_core_email._private.server.EmailUtil import SendEmail
from peek_core_email._private.storage import Setting
from peek_core_email._private.storage.Setting import globalSetting
from peek_core_email.server.EmailApiABC import EmailApiABC
from vortex.DeferUtil import deferToThreadWrapWithLogger

logger = logging.getLogger(__name__)


class EmailApi(EmailApiABC):
    def __init__(self, ormSessionCreator):
        self._ormSessionCreator = ormSessionCreator

    def shutdown(self):
        pass

    @deferToThreadWrapWithLogger(logger)
    def sendSms(self, mobile: str, contents: str) -> None:

        session = self._ormSessionCreator()

        try:

            settings = globalSetting(session)

            if not settings[Setting.EMAIL_ENABLED]:
                logger.debug("SMS sending is disabled, not sending to '%s' for : %s",
                             mobile, contents)
                return

            smsEmailPostfix = settings[Setting.SMS_NUMBER_EMAIL_POSTFIX]

            email = mobile + smsEmailPostfix
            email = email.replace("+", "")

            emailer = SendEmail(self._ormSessionCreator)
            emailer.sendBlocking(
                message=contents,
                subject="",
                recipients=[email],
                html=False
            )

        finally:
            session.close()

    @deferToThreadWrapWithLogger(logger)
    def sendEmail(self, addresses: List[str], subject: str,
                  contents: str, isHtml: bool) -> None:
        session = self._ormSessionCreator()

        try:

            settings = globalSetting(session)

            if not settings[Setting.EMAIL_ENABLED]:
                logger.debug("Email sending is disabled, not sending to '%s' for : %s",
                             addresses, subject)
                return

            emailer = SendEmail(self._ormSessionCreator)

            emailer.sendBlocking(
                message=contents,
                subject=subject,
                recipients=addresses,
                html=isHtml
            )

        finally:
            session.close()



import logging
import smtplib
from email.mime.text import MIMEText
from typing import List

from peek_core_email._private.storage import Setting
from peek_core_email._private.storage.Setting import globalSetting

logger = logging.getLogger(__name__)


class SendEmail(object):
    def __init__(self, dbSessionCreator):
        settings = globalSetting(dbSessionCreator)
        self._smtpHost = settings[Setting.EMAIL_SMTP_HOST]
        self._sender = settings[Setting.EMAIL_SENDER]

    def sendBlocking(self, message: str, subject: str, recipients: List[str], html=False):
        """
        Send email to one or more addresses.
        """

        if not recipients:
            raise Exception("Receipient is missing")

        msg = MIMEText(message, 'html' if html else 'plain')
        msg['Subject'] = subject
        msg['From'] = self._sender
        msg['To'] = ', '.join(recipients)
        msg.preamble = subject

        # Send the message via our own SMTP server.
        s = smtplib.SMTP(self._smtpHost)
        s.send_message(msg)
        s.quit()
